prettyqt.core package
=====================

Submodules
----------

prettyqt.core.settings module
-----------------------------

.. automodule:: prettyqt.core.settings
    :members:
    :undoc-members:
    :show-inheritance:

prettyqt.core.transposeproxymodel module
----------------------------------------

.. automodule:: prettyqt.core.transposeproxymodel
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: prettyqt.core
    :members:
    :undoc-members:
    :show-inheritance:
